@@ -5,7 +5,7 @@ import os
 import locale
 from sqlalchemy.orm import relationship, mapper
 from sqlalchemy.sql import and_
-from sqlalchemy import (Column, Table, Integer, ForeignKey, Unicode, Float,
+from sqlalchemy import (Column, Table, Integer, ForeignKey, Float,
                         MetaData, Boolean, VARCHAR)
 from sqlalchemy.engine import create_engine
 from sqlalchemy.orm import scoped_session, sessionmaker
@@ -175,9 +175,11 @@ class Building(Entity, Mapping):
     def fetch_apartments(self, available_only=False, floors=None,
                          room_count=None):
         query = session.query(Apartment)\
-                       .filter(apartments.c.project_title==self.project_title,
-                               apartments.c.quarter_number==self.quarter_number,
-                               apartments.c.building_number==self.number)
+                       .filter(apartments.c.project_title ==
+                               self.project_title,
+                               apartments.c.quarter_number ==
+                               self.quarter_number,
+                               apartments.c.building_number == self.number)
         if floors:
             floor_list = list(floors)
             query = query.filter(apartments.c.floor_number.in_(floor_list))
@@ -362,9 +364,7 @@ class Apartment(Entity, Mapping):
 
     @classmethod
     def add(cls, project_title, number, quarter_number=0, building_number=0,
-            section_number=0, floor_number=0, square=None,
-            room_count=None, square_out=None, status=None,
-            cost_per_meter=None, total_cost=None, note=None):
+            section_number=0, floor_number=0, **attribs):
         project = Project.fetch(project_title) or Project(project_title)
         quarter = Quarter.fetch((project_title, quarter_number)) or \
             Quarter(quarter_number)
@@ -396,13 +396,8 @@ class Apartment(Entity, Mapping):
         apartment.building_number = building_number
         apartment.floor_number = floor_number
         apartment.number = number
-        apartment.room_count = room_count
-        apartment.square = square
-        apartment.square_out = square_out
-        apartment.status = status
-        apartment.cost_per_meter = cost_per_meter
-        apartment.total_cost = total_cost
-        apartment.note = note
+        for attr_name, value in attribs.iteritems():
+            setattr(apartment, attr_name, value)
         return apartment
 
     def area_coords(self, floor_dir=None, size=None, reverse=False,
